Range<T extends num> class

Implemented types
Implementers

Constructors

Range(T start, T end)
const
Range.fromSize(T start, {required T size})

Properties

end → T
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start → T
final

Methods

compareTo(Range<num> other) int
Compares this object to another object.
override
contains(num number) bool
Whether the given number lies within this range.
includes<S extends num>(Range<S> other) bool
Whether the range other is fully contained by this one.
intersection<O extends num>(Range<num> other, {MergingStrategy? strategy}) Range<O>
isAdjacent<S extends num>(Range<S> other) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sharesRangeWith<S extends num>(Range<S> other) bool
Whether there is any overlap between this range and other.
toString() String
A string representation of this object.
override

Operators

operator &(Range<num> other) Range<num>
operator ==(Object other) bool
The equality operator.
override

Static Properties

global MergingStrategy?
getter/setter pair

Static Methods

integer(int start, int end) Range<int>