Range<T extends num> class
- Implemented types
-
- Comparable<
Range< T> >
- Comparable<
- Implementers
Constructors
- Range(T start, T end)
-
const
- Range.fromSize(T start, {required T size})
Properties
Methods
-
compareTo(
Range< num> other) → int -
Compares this object to another object.
override
-
contains(
num number) → bool -
Whether the given
numberlies within this range. -
includes<
S extends num> (Range< S> other) → bool -
Whether the range
otheris fully contained by this one. -
intersection<
O extends num> (Range< num> other, {MergingStrategy? strategy}) → Range<O> -
isAdjacent<
S extends num> (Range< S> other) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
Whether there is any overlap between this range and
other. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator &(
Range< num> other) → Range<num> -
operator ==(
Object other) → bool -
The equality operator.
override
Static Properties
- global ↔ MergingStrategy?
-
getter/setter pair